from FilesOp.File import File

__author__ = """KingKaitoKid"""
__email__ = 'djstrix@me.com'
__version__ = '1.0.8'
name = "FilesOp"